# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.core.v3 import backoff_pb2 as envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import udp_socket_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_udp__socket__config__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto\x12)envoy.extensions.filters.udp.udp_proxy.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a\"envoy/config/core/v3/backoff.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a,envoy/config/core/v3/udp_socket_config.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x11\n\x0eUdpProxyConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12%\n\x07\x63luster\x18\x02 \x01(\tB\x12\x18\x01\xfa\x42\x04r\x02\x10\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x39\n\x07matcher\x18\t \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01H\x00\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13use_original_src_ip\x18\x04 \x01(\x08\x12\x65\n\rhash_policies\x18\x05 \x03(\x0b\x32\x44.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicyB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x12\x45\n\x16upstream_socket_config\x18\x06 \x01(\x0b\x32%.envoy.config.core.v3.UdpSocketConfig\x12%\n\x1duse_per_packet_load_balancing\x18\x07 \x01(\x08\x12\x38\n\naccess_log\x18\x08 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12>\n\x10proxy_access_log\x18\n \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12`\n\x0fsession_filters\x18\x0b \x03(\x0b\x32G.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.SessionFilter\x12\x66\n\x10tunneling_config\x18\x0c \x01(\x0b\x32L.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig\x12i\n\x12\x61\x63\x63\x65ss_log_options\x18\r \x01(\x0b\x32M.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpAccessLogOptions\x1a[\n\nHashPolicy\x12\x1c\n\tsource_ip\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x16\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x1a\xac\x01\n\rSessionFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12G\n\x10\x63onfig_discovery\x18\x03 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSourceH\x00\x42\r\n\x0b\x63onfig_type\x1a\xe2\x06\n\x12UdpTunnelingConfig\x12\x1b\n\nproxy_host\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x30\n\nproxy_port\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x0btarget_host\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12(\n\x13\x64\x65\x66\x61ult_target_port\x18\x04 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00\x12\x10\n\x08use_post\x18\x05 \x01(\x08\x12\x11\n\tpost_path\x18\x06 \x01(\t\x12p\n\rretry_options\x18\x07 \x01(\x0b\x32Y.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig.RetryOptions\x12J\n\x0eheaders_to_add\x18\x08 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12r\n\x0e\x62uffer_options\x18\t \x01(\x0b\x32Z.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig.BufferOptions\x12\"\n\x1apropagate_response_headers\x18\n \x01(\x08\x12#\n\x1bpropagate_response_trailers\x18\x0b \x01(\x08\x1a\x87\x01\n\rBufferOptions\x12<\n\x16max_buffered_datagrams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12max_buffered_bytes\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x1a\x8a\x01\n\x0cRetryOptions\x12:\n\x14max_connect_attempts\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x0f\x62\x61\x63koff_options\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.BackoffStrategy\x1a\x8f\x01\n\x13UdpAccessLogOptions\x12J\n\x19\x61\x63\x63\x65ss_log_flush_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12,\n$flush_access_log_on_tunnel_connected\x18\x02 \x01(\x08:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfigB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\x42\xb0\x01\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\x01Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/udp_proxy/v3;udp_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.udp.udp_proxy.v3.udp_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\001Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/udp_proxy/v3;udp_proxyv3\272\200\310\321\006\002\020\002'
  _UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']._serialized_options = b'\370B\001'
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip']._serialized_options = b'\372B\004j\002\010\001'
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['key']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_SESSIONFILTER.fields_by_name['name']._options = None
  _UDPPROXYCONFIG_SESSIONFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['proxy_host']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['proxy_host']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['target_host']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['target_host']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['default_target_port']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['default_target_port']._serialized_options = b'\372B\010*\006\030\377\377\003 \000'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['headers_to_add']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _UDPPROXYCONFIG_UDPACCESSLOGOPTIONS.fields_by_name['access_log_flush_interval']._options = None
  _UDPPROXYCONFIG_UDPACCESSLOGOPTIONS.fields_by_name['access_log_flush_interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _UDPPROXYCONFIG.oneofs_by_name['route_specifier']._options = None
  _UDPPROXYCONFIG.oneofs_by_name['route_specifier']._serialized_options = b'\370B\001'
  _UDPPROXYCONFIG.fields_by_name['stat_prefix']._options = None
  _UDPPROXYCONFIG.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG.fields_by_name['cluster']._options = None
  _UDPPROXYCONFIG.fields_by_name['cluster']._serialized_options = b'\030\001\372B\004r\002\020\001\222\307\206\330\004\0033.0'
  _UDPPROXYCONFIG.fields_by_name['matcher']._options = None
  _UDPPROXYCONFIG.fields_by_name['matcher']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _UDPPROXYCONFIG.fields_by_name['hash_policies']._options = None
  _UDPPROXYCONFIG.fields_by_name['hash_policies']._serialized_options = b'\372B\005\222\001\002\020\001'
  _UDPPROXYCONFIG._options = None
  _UDPPROXYCONFIG._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig'
  _globals['_UDPPROXYCONFIG']._serialized_start=592
  _globals['_UDPPROXYCONFIG']._serialized_end=2830
  _globals['_UDPPROXYCONFIG_HASHPOLICY']._serialized_start=1460
  _globals['_UDPPROXYCONFIG_HASHPOLICY']._serialized_end=1551
  _globals['_UDPPROXYCONFIG_SESSIONFILTER']._serialized_start=1554
  _globals['_UDPPROXYCONFIG_SESSIONFILTER']._serialized_end=1726
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG']._serialized_start=1729
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG']._serialized_end=2595
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_BUFFEROPTIONS']._serialized_start=2319
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_BUFFEROPTIONS']._serialized_end=2454
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_RETRYOPTIONS']._serialized_start=2457
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_RETRYOPTIONS']._serialized_end=2595
  _globals['_UDPPROXYCONFIG_UDPACCESSLOGOPTIONS']._serialized_start=2598
  _globals['_UDPPROXYCONFIG_UDPACCESSLOGOPTIONS']._serialized_end=2741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/ratelimit_strategy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_unit_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/type/v3/ratelimit_strategy.proto\x12\renvoy.type.v3\x1a\"envoy/type/v3/ratelimit_unit.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9e\x03\n\x11RateLimitStrategy\x12N\n\x0c\x62lanket_rule\x18\x01 \x01(\x0e\x32,.envoy.type.v3.RateLimitStrategy.BlanketRuleB\x08\xfa\x42\x05\x82\x01\x02\x10\x01H\x00\x12V\n\x16requests_per_time_unit\x18\x02 \x01(\x0b\x32\x34.envoy.type.v3.RateLimitStrategy.RequestsPerTimeUnitH\x00\x12\x32\n\x0ctoken_bucket\x18\x03 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketH\x00\x1ap\n\x13RequestsPerTimeUnit\x12\x1e\n\x16requests_per_time_unit\x18\x01 \x01(\x04\x12\x39\n\ttime_unit\x18\x02 \x01(\x0e\x32\x1c.envoy.type.v3.RateLimitUnitB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"*\n\x0b\x42lanketRule\x12\r\n\tALLOW_ALL\x10\x00\x12\x0c\n\x08\x44\x45NY_ALL\x10\x01\x42\x0f\n\x08strategy\x12\x03\xf8\x42\x01\x42\x84\x01\n\x1bio.envoyproxy.envoy.type.v3B\x16RatelimitStrategyProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.v3.ratelimit_strategy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.envoyproxy.envoy.type.v3B\026RatelimitStrategyProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _RATELIMITSTRATEGY_REQUESTSPERTIMEUNIT.fields_by_name['time_unit']._options = None
  _RATELIMITSTRATEGY_REQUESTSPERTIMEUNIT.fields_by_name['time_unit']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RATELIMITSTRATEGY.oneofs_by_name['strategy']._options = None
  _RATELIMITSTRATEGY.oneofs_by_name['strategy']._serialized_options = b'\370B\001'
  _RATELIMITSTRATEGY.fields_by_name['blanket_rule']._options = None
  _RATELIMITSTRATEGY.fields_by_name['blanket_rule']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RATELIMITSTRATEGY']._serialized_start=217
  _globals['_RATELIMITSTRATEGY']._serialized_end=631
  _globals['_RATELIMITSTRATEGY_REQUESTSPERTIMEUNIT']._serialized_start=458
  _globals['_RATELIMITSTRATEGY_REQUESTSPERTIMEUNIT']._serialized_end=570
  _globals['_RATELIMITSTRATEGY_BLANKETRULE']._serialized_start=572
  _globals['_RATELIMITSTRATEGY_BLANKETRULE']._serialized_end=614
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/lightstep.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/config/trace/v2/lightstep.proto\x12\x15\x65nvoy.config.trace.v2\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x83\x02\n\x0fLightstepConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\"\n\x11\x61\x63\x63\x65ss_token_file\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12`\n\x11propagation_modes\x18\x03 \x03(\x0e\x32\x36.envoy.config.trace.v2.LightstepConfig.PropagationModeB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\"F\n\x0fPropagationMode\x12\t\n\x05\x45NVOY\x10\x00\x12\r\n\tLIGHTSTEP\x10\x01\x12\x06\n\x02\x42\x33\x10\x02\x12\x11\n\rTRACE_CONTEXT\x10\x03\x42\x85\x01\n#io.envoyproxy.envoy.config.trace.v2B\x0eLightstepProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2.lightstep_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v2B\016LightstepProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\272\200\310\321\006\002\020\001'
  _LIGHTSTEPCONFIG.fields_by_name['collector_cluster']._options = None
  _LIGHTSTEPCONFIG.fields_by_name['collector_cluster']._serialized_options = b'\372B\004r\002 \001'
  _LIGHTSTEPCONFIG.fields_by_name['access_token_file']._options = None
  _LIGHTSTEPCONFIG.fields_by_name['access_token_file']._serialized_options = b'\372B\004r\002 \001'
  _LIGHTSTEPCONFIG.fields_by_name['propagation_modes']._options = None
  _LIGHTSTEPCONFIG.fields_by_name['propagation_modes']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_LIGHTSTEPCONFIG']._serialized_start=121
  _globals['_LIGHTSTEPCONFIG']._serialized_end=380
  _globals['_LIGHTSTEPCONFIG_PROPAGATIONMODE']._serialized_start=310
  _globals['_LIGHTSTEPCONFIG_PROPAGATIONMODE']._serialized_end=380
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/tls_inspector/v3/tls_inspector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/listener/tls_inspector/v3/tls_inspector.proto\x12\x32\x65nvoy.extensions.filters.listener.tls_inspector.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x01\n\x0cTlsInspector\x12=\n\x19\x65nable_ja3_fingerprinting\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x18initial_read_buffer_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x10\x81\x80\x04 \xff\x01:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.listener.tls_inspector.v2.TlsInspectorB\xca\x01\n@io.envoyproxy.envoy.extensions.filters.listener.tls_inspector.v3B\x11TlsInspectorProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/tls_inspector/v3;tls_inspectorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.listener.tls_inspector.v3.tls_inspector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.filters.listener.tls_inspector.v3B\021TlsInspectorProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/tls_inspector/v3;tls_inspectorv3\272\200\310\321\006\002\020\002'
  _TLSINSPECTOR.fields_by_name['initial_read_buffer_size']._options = None
  _TLSINSPECTOR.fields_by_name['initial_read_buffer_size']._serialized_options = b'\372B\t*\007\020\201\200\004 \377\001'
  _TLSINSPECTOR._options = None
  _TLSINSPECTOR._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.listener.tls_inspector.v2.TlsInspector'
  _globals['_TLSINSPECTOR']._serialized_start=250
  _globals['_TLSINSPECTOR']._serialized_end=472
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/server_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/admin/v2alpha/server_info.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\"\xef\x02\n\nServerInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x34\n\x05state\x18\x02 \x01(\x0e\x32%.envoy.admin.v2alpha.ServerInfo.State\x12\x37\n\x14uptime_current_epoch\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11uptime_all_epochs\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13hot_restart_version\x18\x05 \x01(\t\x12\x45\n\x14\x63ommand_line_options\x18\x06 \x01(\x0b\x32\'.envoy.admin.v2alpha.CommandLineOptions\"G\n\x05State\x12\x08\n\x04LIVE\x10\x00\x12\x0c\n\x08\x44RAINING\x10\x01\x12\x14\n\x10PRE_INITIALIZING\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03\"\xce\x07\n\x12\x43ommandLineOptions\x12\x0f\n\x07\x62\x61se_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x63oncurrency\x18\x02 \x01(\r\x12\x13\n\x0b\x63onfig_path\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x04 \x01(\t\x12#\n\x1b\x61llow_unknown_static_fields\x18\x05 \x01(\x08\x12%\n\x1dreject_unknown_dynamic_fields\x18\x1a \x01(\x08\x12\x1a\n\x12\x61\x64min_address_path\x18\x06 \x01(\t\x12S\n\x18local_address_ip_version\x18\x07 \x01(\x0e\x32\x31.envoy.admin.v2alpha.CommandLineOptions.IpVersion\x12\x11\n\tlog_level\x18\x08 \x01(\t\x12\x1b\n\x13\x63omponent_log_level\x18\t \x01(\t\x12\x12\n\nlog_format\x18\n \x01(\t\x12\x1a\n\x12log_format_escaped\x18\x1b \x01(\x08\x12\x10\n\x08log_path\x18\x0b \x01(\t\x12\x17\n\x0fservice_cluster\x18\r \x01(\t\x12\x14\n\x0cservice_node\x18\x0e \x01(\t\x12\x14\n\x0cservice_zone\x18\x0f \x01(\t\x12\x36\n\x13\x66ile_flush_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\ndrain_time\x18\x11 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x14parent_shutdown_time\x18\x12 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x04mode\x18\x13 \x01(\x0e\x32,.envoy.admin.v2alpha.CommandLineOptions.Mode\x12\x1b\n\tmax_stats\x18\x14 \x01(\x04\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\"\n\x10max_obj_name_len\x18\x15 \x01(\x04\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x1b\n\x13\x64isable_hot_restart\x18\x16 \x01(\x08\x12\x1c\n\x14\x65nable_mutex_tracing\x18\x17 \x01(\x08\x12\x15\n\rrestart_epoch\x18\x18 \x01(\r\x12\x16\n\x0e\x63puset_threads\x18\x19 \x01(\x08\x12\x1b\n\x13\x64isabled_extensions\x18\x1c \x03(\t\"\x1b\n\tIpVersion\x12\x06\n\x02v4\x10\x00\x12\x06\n\x02v6\x10\x01\"-\n\x04Mode\x12\t\n\x05Serve\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\x0c\n\x08InitOnly\x10\x02J\x04\x08\x0c\x10\rBz\n!io.envoyproxy.envoy.admin.v2alphaB\x0fServerInfoProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.server_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\017ServerInfoProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _COMMANDLINEOPTIONS.fields_by_name['max_stats']._options = None
  _COMMANDLINEOPTIONS.fields_by_name['max_stats']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _COMMANDLINEOPTIONS.fields_by_name['max_obj_name_len']._options = None
  _COMMANDLINEOPTIONS.fields_by_name['max_obj_name_len']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _globals['_SERVERINFO']._serialized_start=163
  _globals['_SERVERINFO']._serialized_end=530
  _globals['_SERVERINFO_STATE']._serialized_start=459
  _globals['_SERVERINFO_STATE']._serialized_end=530
  _globals['_COMMANDLINEOPTIONS']._serialized_start=533
  _globals['_COMMANDLINEOPTIONS']._serialized_end=1507
  _globals['_COMMANDLINEOPTIONS_IPVERSION']._serialized_start=1427
  _globals['_COMMANDLINEOPTIONS_IPVERSION']._serialized_end=1454
  _globals['_COMMANDLINEOPTIONS_MODE']._serialized_start=1456
  _globals['_COMMANDLINEOPTIONS_MODE']._serialized_end=1501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/dayofweek.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgoogle/type/dayofweek.proto\x12\x0bgoogle.type*\x84\x01\n\tDayOfWeek\x12\x1b\n\x17\x44\x41Y_OF_WEEK_UNSPECIFIED\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\x42i\n\x0f\x63om.google.typeB\x0e\x44\x61yOfWeekProtoP\x01Z>google.golang.org/genproto/googleapis/type/dayofweek;dayofweek\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.dayofweek_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\016DayOfWeekProtoP\001Z>google.golang.org/genproto/googleapis/type/dayofweek;dayofweek\242\002\003GTP'
  _globals['_DAYOFWEEK']._serialized_start=45
  _globals['_DAYOFWEEK']._serialized_end=177
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/node.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.type.matcher import struct_pb2 as envoy_dot_type_dot_matcher_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65nvoy/type/matcher/node.proto\x12\x12\x65nvoy.type.matcher\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1f\x65nvoy/type/matcher/struct.proto\x1a\x1dudpa/annotations/status.proto\"|\n\x0bNodeMatcher\x12\x32\n\x07node_id\x18\x01 \x01(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x39\n\x0enode_metadatas\x18\x02 \x03(\x0b\x32!.envoy.type.matcher.StructMatcherBr\n io.envoyproxy.envoy.type.matcherB\tNodeProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\tNodeProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _globals['_NODEMATCHER']._serialized_start=150
  _globals['_NODEMATCHER']._serialized_end=274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/gcp_authn/v3/gcp_authn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/gcp_authn/v3/gcp_authn.proto\x12*envoy.extensions.filters.http.gcp_authn.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xff\x02\n\x14GcpAuthnFilterConfig\x12<\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUriB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x37\n\x0cretry_policy\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy\x12R\n\x0c\x63\x61\x63he_config\x18\x03 \x01(\x0b\x32<.envoy.extensions.filters.http.gcp_authn.v3.TokenCacheConfig\x12M\n\x0ctoken_header\x18\x04 \x01(\x0b\x32\x37.envoy.extensions.filters.http.gcp_authn.v3.TokenHeader\x12\x0f\n\x07\x63luster\x18\x05 \x01(\t\x12<\n\x07timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x10\xfa\x42\r\xaa\x01\n\x1a\x06\x08\x80\x80\x80\x80\x10\x32\x00\" \n\x08\x41udience\x12\x14\n\x03url\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x10TokenCacheConfig\x12\x41\n\ncache_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x0f\xfa\x42\x0c\x32\n\x18\xff\xff\xff\xff\xff\xff\xff\xff\x7f\"M\n\x0bTokenHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12!\n\x0cvalue_prefix\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x42\xb2\x01\n8io.envoyproxy.envoy.extensions.filters.http.gcp_authn.v3B\rGcpAuthnProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gcp_authn/v3;gcp_authnv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.gcp_authn.v3.gcp_authn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.gcp_authn.v3B\rGcpAuthnProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gcp_authn/v3;gcp_authnv3\272\200\310\321\006\002\020\002'
  _GCPAUTHNFILTERCONFIG.fields_by_name['http_uri']._options = None
  _GCPAUTHNFILTERCONFIG.fields_by_name['http_uri']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _GCPAUTHNFILTERCONFIG.fields_by_name['timeout']._options = None
  _GCPAUTHNFILTERCONFIG.fields_by_name['timeout']._serialized_options = b'\372B\r\252\001\n\032\006\010\200\200\200\200\0202\000'
  _AUDIENCE.fields_by_name['url']._options = None
  _AUDIENCE.fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _TOKENCACHECONFIG.fields_by_name['cache_size']._options = None
  _TOKENCACHECONFIG.fields_by_name['cache_size']._serialized_options = b'\372B\0142\n\030\377\377\377\377\377\377\377\377\177'
  _TOKENHEADER.fields_by_name['name']._options = None
  _TOKENHEADER.fields_by_name['name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _TOKENHEADER.fields_by_name['value_prefix']._options = None
  _TOKENHEADER.fields_by_name['value_prefix']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _globals['_GCPAUTHNFILTERCONFIG']._serialized_start=334
  _globals['_GCPAUTHNFILTERCONFIG']._serialized_end=717
  _globals['_AUDIENCE']._serialized_start=719
  _globals['_AUDIENCE']._serialized_end=751
  _globals['_TOKENCACHECONFIG']._serialized_start=753
  _globals['_TOKENCACHECONFIG']._serialized_end=838
  _globals['_TOKENHEADER']._serialized_start=840
  _globals['_TOKENHEADER']._serialized_end=917
# @@protoc_insertion_point(module_scope)
